# lingo - payment and billing system
# Copyright (C) 2022  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.shortcuts import get_object_or_404
from django.utils.translation import gettext_noop as N_
from rest_framework import permissions
from rest_framework.views import APIView

from lingo.agendas.models import Agenda
from lingo.api import serializers
from lingo.api.utils import APIErrorBadRequest, Response
from lingo.invoicing.models import Regie


class AgendaCheckTypeList(APIView):
    permission_classes = ()

    def get(self, request, agenda_identifier=None, format=None):
        agenda = get_object_or_404(Agenda, slug=agenda_identifier)

        check_types = []
        if agenda.check_type_group:
            check_types = [
                {'id': x.slug, 'text': x.label, 'kind': x.kind}
                for x in agenda.check_type_group.check_types.filter(disabled=False)
            ]
        return Response({'data': check_types})


agenda_check_type_list = AgendaCheckTypeList.as_view()


class PricingCompute(APIView):
    permission_classes = (permissions.IsAuthenticated,)
    serializer_class = serializers.PricingComputeSerializer

    def get(self, request, format=None):
        serializer = self.serializer_class(data=request.query_params)
        if not serializer.is_valid():
            raise APIErrorBadRequest(N_('invalid payload'), errors=serializer.errors)

        return Response({'data': serializer.compute(self.request)})


pricing_compute = PricingCompute.as_view()


class InvoicingRegies(APIView):
    permission_classes = (permissions.IsAuthenticated,)

    def get(self, request, format=None):
        return Response(
            {
                'data': [
                    {'id': regie.slug, 'text': regie.label, 'slug': regie.slug}
                    for regie in Regie.objects.order_by('label')
                ]
            }
        )


invoicing_regies = InvoicingRegies.as_view()
